.. _Auto Label:

Automatic Annotation
--------------------

Because the image list for project creation in :ref:`Scalabel Format` can also
contain labels within each frame. For example, you can upload an image list like
`examples/image_list_with_auto_labels.json
<https://github.com/scalabel/scalabel/blob/master/examples/image_list_with_auto_labels.json>`_.
The labels in this email list are generated by an object detector. The labels
will be automatically loaded in the tasks and shown to the annotator for
adjustment.

You can use an off-shelf object detector such as `Faster RCNN
<https://github.com/facebookresearch/maskrcnn-benchmark>`_. If the results
generated by the detector is in COCO format, you can use `the conversion script
<https://github.com/scalabel/scalabel/blob/master/scalabel/tools/coco2scalabel.py>`_ to
convert the results to :ref:`Scalabel format`.

Another use of this function is to provide further annotatoin adjustment for existing
labels generated by `Scalabel <https://www.scalabel.ai>`_. You can directly
upload the exported results from a previous annotation project and the labels
will show up again in the new tasks.
